summaryrefslogtreecommitdiffstats
path: root/src/usr/isteps/istep16
diff options
context:
space:
mode:
authorJoe McGill <jmcgill@us.ibm.com>2017-05-02 13:21:24 -0500
committerDaniel M. Crowell <dcrowell@us.ibm.com>2017-05-22 09:54:45 -0400
commit6a3b0f5ac79e28f358e83464065fda5f85b810cb (patch)
treec5e5291be9d7df5384fad1395a26c8891d0addb3 /src/usr/isteps/istep16
parent529ea1d267e13c9556dc490a5587de9a0d6e3e4e (diff)
downloadtalos-hostboot-6a3b0f5ac79e28f358e83464065fda5f85b810cb.tar.gz
talos-hostboot-6a3b0f5ac79e28f358e83464065fda5f85b810cb.zip
security -- split p9_chiplet_scominit and p9_chiplet_enable_ridi isteps
p9_chiplet_scominit, move from istep 8 to istep 10 shift content required for XBUS, fabric establishment into p9_chiplet_fabric_scominit, to be called in istep 8 p9_chiplet_enable_ridi, move from istep 8 to istep 10 shift content required for XBUS establishment into p9_xbus_enable_ridi, to be called in istep CMVC-Coreq: 1023401 Change-Id: I4c60e4c41211976c7919a603ab679357cc4af106 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/39956 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Tested-by: Hostboot CI <hostboot-ci+hostboot@us.ibm.com> Reviewed-by: Brent Wieman <bwieman@us.ibm.com> Dev-Ready: Brent Wieman <bwieman@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com> Reviewed-by: Jennifer A. Stofer <stofer@us.ibm.com> Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/39960 Tested-by: Jenkins OP Build CI <op-jenkins+hostboot@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com>
Diffstat (limited to 'src/usr/isteps/istep16')
-rw-r--r--src/usr/isteps/istep16/call_host_secure_rng.C (renamed from src/usr/isteps/istep16/call_p9_rng_init_phase2.C)14
-rw-r--r--src/usr/isteps/istep16/makefile2
2 files changed, 8 insertions, 8 deletions
diff --git a/src/usr/isteps/istep16/makefile b/src/usr/isteps/istep16/makefile
index c04dc08f2..03841b227 100644
--- a/src/usr/isteps/istep16/makefile
+++ b/src/usr/isteps/istep16/makefile
@@ -41,7 +41,7 @@ EXTRAINCDIR += ${ROOTPATH}/src/import/chips/p9/utils/imageProcs/
OBJS += call_host_activate_master.o
OBJS += call_host_activate_slave_cores.o
-OBJS += call_p9_rng_init_phase2.o
+OBJS += call_host_secure_rng.o
OBJS += call_mss_scrub.o
OBJS += call_host_ipl_complete.o
OpenPOWER on IntegriCloud
diff --git a/src/usr/isteps/istep16/call_p9_rng_init_phase2.C b/src/usr/isteps/istep16/call_host_secure_rng.C
index 4aeb4917e..5a5150475 100644
--- a/src/usr/isteps/istep16/call_p9_rng_init_phase2.C
+++ b/src/usr/isteps/istep16/call_host_secure_rng.C
@@ -1,7 +1,7 @@
/* IBM_PROLOG_BEGIN_TAG */
/* This is an automatically generated prolog. */
/* */
-/* $Source: src/usr/isteps/istep16/call_p9_rng_init_phase2.C $ */
+/* $Source: src/usr/isteps/istep16/call_host_secure_rng.C $ */
/* */
/* OpenPOWER HostBoot Project */
/* */
@@ -24,7 +24,7 @@
/* IBM_PROLOG_END_TAG */
/**
- * @file call_p9_rng_init_phase2.C
+ * @file call_host_secure_rng.C
*
* Support file for IStep: core_activate
* Core Activate
@@ -70,16 +70,16 @@ using namespace ERRORLOG;
using namespace TARGETING;
//******************************************************************************
// wrapper function to call p9_rng_init_phase2
//******************************************************************************
-void* call_p9_rng_init_phase2( void *io_pArgs )
+void* call_host_secure_rng( void *io_pArgs )
{
errlHndl_t l_err = NULL;
IStepError l_StepError;
TRACFCOMP( ISTEPS_TRACE::g_trac_isteps_trace,
- "call_p9_rng_init_phase2 entry" );
+ "call_host_secure_rng entry" );
//
// get a list of all the procs in the system
//
@@ -93,7 +93,7 @@ void* call_p9_rng_init_phase2( void *io_pArgs )
l_cpu_target);
TRACFCOMP( ISTEPS_TRACE::g_trac_isteps_trace,
- "Running p9_rng_init_phase2 HWP on processor target %.8X",
+ "Running host_secure_rng HWP on processor target %.8X",
TARGETING::get_huid(l_cpu_target) );
FAPI_INVOKE_HWP(l_err, p9_rng_init_phase2, l_fapi2_proc_target);
@@ -109,7 +109,7 @@ void* call_p9_rng_init_phase2( void *io_pArgs )
} // end of going through all processors
TRACFCOMP( ISTEPS_TRACE::g_trac_isteps_trace,
- "call_p9_rng_init_phase2 exit");
+ "call_host_secure_rng exit");
return l_StepError.getErrorHandle();
}
@@ -70,16 +70,16 @@ using namespace ERRORLOG;
using namespace TARGETING;
//******************************************************************************
-// wrapper function to call p9_rng_init_phase2
+// wrapper function to call host_secure_rng
//******************************************************************************